<?xml version="1.0" encoding="shift_jis"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" > 
<xsl:import href="./common.xsl"/>
<xsl:output method="html" doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN" />

<!-- ****** TOP ****** -->

<xsl:template match="/">
	<xsl:apply-templates select="dynamic_document">
		<xsl:with-param name="select_type" select="'2'"/>
		<xsl:with-param name="data_type" select="$TARGET_CS_COMPONENT"/>
		<xsl:with-param name="id" select="$HEADER_ID"/>
	</xsl:apply-templates>
</xsl:template>

<!-- ****** HEADER ****** -->

<xsl:template match="header">
	<xsl:call-template name="sub_links"/>
	<xsl:call-template name="frame_info"/>

	<xsl:call-template name="title_tab">
		<xsl:with-param name="name" select="concat($COMPONENT,$DETAIL)"/>
		<xsl:with-param name="image" select="$IMG_COMPONENT"/>
	</xsl:call-template>

<xsl:element name="table">
	<xsl:attribute name="class">main</xsl:attribute>
	<xsl:attribute name="summary">component</xsl:attribute>

	<xsl:element name="tr">
		<xsl:attribute name="style">width:150px;</xsl:attribute>
		<xsl:element name="th">
			<xsl:attribute name="style">width:30%</xsl:attribute><xsl:value-of select="$LOGICAL_NAME" />
		</xsl:element>
		<xsl:element name="td"><xsl:value-of select="logical_name" /></xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$PHYSICAL_NAME" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="physical_name" /></xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$COMMENT" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="memo" /></xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$BASE_CLASS" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="base_class/logical_name" /><xsl:element name="br" /><xsl:value-of select="base_class/physical_name" /></xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$TEXT" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="text" /></xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$TOOLTIP_TEXT" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="tooltip_text" /></xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="concat($LAYOUT_X,$LAYOUT_Y)" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="x_pos" />F<xsl:value-of select="y_pos" /></xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="concat($LAYOUT_H,$LAYOUT_W)" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="height" />F<xsl:value-of select="width" /></xsl:element>
	</xsl:element>
</xsl:element>
</xsl:template>



<!-- ****** DETAIL ****** -->

<xsl:template match="detail">
	<!-- item -->
	<xsl:if test="$HREF = 'item'">
		<xsl:apply-templates select="items" />
	</xsl:if>
	<!-- timing -->
	<xsl:if test="$HREF = 'timing'">
		<xsl:apply-templates select="executions" />
	</xsl:if>
	<!-- property -->
	<xsl:if test="$HREF = 'property'">
		<xsl:call-template name="property" />
	</xsl:if>

</xsl:template>

<!-- ****** ITEMS ****** -->

<xsl:template match="items">
	<xsl:element name="br" />
	<xsl:element name="table">
		<xsl:attribute name="class">main</xsl:attribute>
		<xsl:attribute name="summary">Item</xsl:attribute>
		
		<xsl:element name="tr">
			<xsl:attribute name="style">width:100%</xsl:attribute>
			<xsl:element name="th">
				<xsl:attribute name="colspan">2</xsl:attribute><xsl:value-of select="$ITEM" />
			</xsl:element>
			<xsl:element name="th"><xsl:value-of select="$ITEM_TYPE" /></xsl:element>
			<xsl:element name="th">
				<xsl:attribute name="colspan">2</xsl:attribute><xsl:value-of select="$DATA" />
			</xsl:element>
		</xsl:element>

		<xsl:for-each select="record">
			<xsl:element name="tr">
				<xsl:element name="td">
					<xsl:attribute name="class">image</xsl:attribute><xsl:call-template name="image_of_item"/>
				</xsl:element>
				<xsl:element name="td">
					<xsl:element name="a">
					<xsl:attribute name="href">
						<xsl:call-template name="create_link">
							<xsl:with-param name="data_type" select="$TARGET_CS_ITEM"/>
							<xsl:with-param name="select_type" select="2"/>
							<xsl:with-param name="id" select="./id"/>
						</xsl:call-template>
					</xsl:attribute>
						<xsl:value-of select="logical_name" /><xsl:element name="br" /><xsl:value-of select="physical_name" />
					</xsl:element>
				</xsl:element>
				<xsl:element name="td"><xsl:value-of select="item_type" /></xsl:element>
				
				<xsl:element name="td">
					<xsl:attribute name="class">image</xsl:attribute><xsl:call-template name="image_of_data"/>
				</xsl:element>

				<xsl:element name="td">
					<xsl:attribute name="style">width:30%</xsl:attribute>
					<xsl:if test="data/id[.!='']">
					<xsl:element name="a">
						<xsl:attribute name="href">
							<xsl:call-template name="create_link">
								<xsl:with-param name="data_type" select="$TARGET_DAT_DATA"/>
								<xsl:with-param name="select_type" select="3"/>
								<xsl:with-param name="id" select="data/id"/>
							</xsl:call-template>
						</xsl:attribute>
						<xsl:value-of select="data/logical_name" /><xsl:element name="br" /><xsl:value-of select="data/physical_name" />
					</xsl:element>
					</xsl:if>
				</xsl:element>
			</xsl:element>
		</xsl:for-each>
	</xsl:element>
</xsl:template>



</xsl:stylesheet>
