<?xml version="1.0" encoding="shift_jis"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" > 
<xsl:import href="./common.xsl"/>
<xsl:output method="html" doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN" />

<!-- ****** TOP ****** -->
<xsl:template match="/">
	<xsl:apply-templates select="dynamic_document">
		<xsl:with-param name="select_type" select="'2'"/>
		<xsl:with-param name="data_type" select="$TARGET_CS_CRULE"/>
		<xsl:with-param name="id" select="$HEADER_ID"/>
	</xsl:apply-templates>
</xsl:template>

<!-- ****** HEADER ****** -->
<xsl:template match="header">
	<xsl:call-template name="sub_links"/>
	<xsl:call-template name="frame_info"/>

	<xsl:call-template name="title_tab">
		<xsl:with-param name="name" select="concat($BUSINESSRULE,$DETAIL)"/>
		<xsl:with-param name="image" select="$IMG_RULE"/>
	</xsl:call-template>

<xsl:element name="table">
	<xsl:attribute name="class">main</xsl:attribute>
	<xsl:attribute name="summary"><xsl:value-of select="$BUSINESSRULE" /><xsl:value-of select="$DETAIL" /></xsl:attribute>

	<xsl:element name="tr">
		<xsl:attribute name="style">width:100%</xsl:attribute>
		<xsl:element name="th">
			<xsl:attribute name="style">width:30%</xsl:attribute><xsl:value-of select="$LOGICAL_NAME" />
		</xsl:element>
		<xsl:element name="td"><xsl:value-of select="logical_name" /></xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$PHYSICAL_NAME" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="physical_name" /></xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$COMMENT" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="memo" /></xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$TYPE" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="type" /></xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$PARAMETER" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="param" /></xsl:element>
	</xsl:element>
	<xsl:if test="type[.='Normal']">
		<xsl:element name="tr">
			<xsl:element name="th"><xsl:value-of select="$BASE_CLASS" /></xsl:element>
			<xsl:element name="td">
				<xsl:if test="base_class/id[.!='']">
				<xsl:element name="a">
					<xsl:attribute name="href">
						<xsl:call-template name="create_link">
							<xsl:with-param name="data_type" select="$TARGET_OMC_LOGIC"/>
							<xsl:with-param name="select_type" select="3"/>
							<xsl:with-param name="id" select="base_class/id"/>
						</xsl:call-template>
					</xsl:attribute>
					<xsl:value-of select="base_class/logical_name" /><xsl:element name="br" /><xsl:value-of select="base_class/physical_name" /><xsl:element name="br" /><xsl:value-of select="base_class/class_name" />
				</xsl:element>
			</xsl:if>
			</xsl:element>
		</xsl:element>
	</xsl:if>
	<xsl:if test="type[.='FrameShow']">
		<xsl:element name="tr">
			<xsl:element name="th"><xsl:value-of select="$LOAD" /><xsl:value-of select="$FRAME" /></xsl:element>
			<xsl:element name="td">
			<xsl:if test="adapter/id[.!='']">
				<xsl:element name="a">
					<xsl:attribute name="href">
						<xsl:call-template name="create_link">
							<xsl:with-param name="data_type" select="$TARGET_CS_JAVACLIENT"/>
							<xsl:with-param name="select_type" select="2"/>
							<xsl:with-param name="id" select="adapter/id"/>
						</xsl:call-template>
					</xsl:attribute>
					<xsl:value-of select="adapter/logical_name" /><xsl:element name="br" /><xsl:value-of select="adapter/physical_name" />
				</xsl:element>
			</xsl:if>
			</xsl:element>
		</xsl:element>
	</xsl:if>
	<xsl:if test="type[.='FrameClose']">
		<xsl:element name="tr">
			<xsl:element name="th"><xsl:value-of select="$UNLOAD" /><xsl:value-of select="$FRAME" /></xsl:element>
			<xsl:element name="td">
			<xsl:if test="adapter/id[.!='']">
				<xsl:element name="a">
					<xsl:attribute name="href">
						<xsl:call-template name="create_link">
							<xsl:with-param name="data_type" select="$TARGET_CS_JAVACLIENT"/>
							<xsl:with-param name="select_type" select="2"/>
							<xsl:with-param name="id" select="adapter/id"/>
						</xsl:call-template>
					</xsl:attribute>
					<xsl:value-of select="adapter/logical_name" /><xsl:element name="br" /><xsl:value-of select="adapter/physical_name" />
				</xsl:element>
			</xsl:if>
			</xsl:element>
		</xsl:element>
	</xsl:if>
</xsl:element>

</xsl:template>

<!-- ****** DETAIL ****** -->

<xsl:template match="detail">
	<!-- RECORD -->
	<xsl:if test="$HREF = 'io'">
		<xsl:call-template name="write_record">
			<xsl:with-param name="data_type" select="$TARGET_CS_ITEM" />
		</xsl:call-template>
	</xsl:if>
	<xsl:if test="$HREF = 'timing'">
		<xsl:element name="br" />
		<xsl:call-template name="write_timing" />
	</xsl:if>
	<xsl:if test="$HREF = 'structure_l'">
		<xsl:element name="br" />
		<xsl:apply-templates select="structure" />
	</xsl:if>
	<xsl:if test="$HREF = 'structure_p'">
		<xsl:element name="br" />
		<xsl:apply-templates select="structure">
			<xsl:with-param name="type" select="'p'"/>
		</xsl:apply-templates>
	</xsl:if>

</xsl:template>

<!-- **************************************** -->

<xsl:template match="structure">
<xsl:param name="type" />

<xsl:if test="@type[.='try']">

<xsl:element name="span">
<xsl:attribute name="style">font-weight:bold;font-size:1.2em</xsl:attribute>
try{
</xsl:element>

<xsl:element name="ol">
<xsl:for-each select="record">
	<xsl:element name="li">
	<xsl:attribute name="style">margin-bottom:10;</xsl:attribute>

	<xsl:call-template name="item_record">
		<xsl:with-param name="type" select="$type"/>
	</xsl:call-template>
	<xsl:element name="br" />
		<xsl:for-each select="after/record">
			(<xsl:number level="single" format="1" count="after/record" />). 
			<xsl:call-template name="after_record">
				<xsl:with-param name="type" select="$type"/>
			</xsl:call-template>
			<xsl:call-template name="user_error"/>
			<xsl:apply-templates select="structure">
				<xsl:with-param name="type" select="$type"/>
			</xsl:apply-templates>
		</xsl:for-each>
	</xsl:element>
</xsl:for-each>
</xsl:element>

<xsl:element name="span">
<xsl:attribute name="style">font-weight:bold;font-size:1.2em</xsl:attribute>
}
</xsl:element>

<xsl:for-each select="catch">
<xsl:element name="span">
<xsl:attribute name="style">font-weight:bold;font-size:1.2em</xsl:attribute>
catch( 
		<xsl:call-template name="error_flg_item_record">
			<xsl:with-param name="type" select="$type"/>
		</xsl:call-template>
 == <xsl:number level="single" format="1" count="catch" /> ) {
</xsl:element>

<xsl:element name="ul">
	<xsl:element name="li">
		<xsl:call-template name="item_record">
			<xsl:with-param name="type" select="$type"/>
		</xsl:call-template>
		<xsl:element name="br" />
		<xsl:for-each select="after/record">
			<xsl:call-template name="after_record">
				<xsl:with-param name="type" select="$type"/>
			</xsl:call-template>
			<xsl:call-template name="user_error" />
			<xsl:apply-templates select="structure">
				<xsl:with-param name="type" select="$type"/>
			</xsl:apply-templates>
		</xsl:for-each>
	</xsl:element>
</xsl:element>
<xsl:element name="span">
<xsl:attribute name="style">font-weight:bold;font-size:1.2em</xsl:attribute>
}</xsl:element>
<xsl:element name="br" />
</xsl:for-each>

</xsl:if>

<!-- IF̏ꍇ -->
<xsl:if test="@type[.='if']">
<xsl:element name="div">
<xsl:attribute name="style">margin-left:3%</xsl:attribute>

<xsl:for-each select="record">
<xsl:element name="span">
<xsl:attribute name="style">font-weight:bold;font-size:1.2em</xsl:attribute>
<xsl:value-of select="@name" />(
</xsl:element>


	<xsl:for-each select="if">
	<xsl:element name="ul">
		<xsl:element name="li">
		<xsl:attribute name="style">margin-bottom:10;</xsl:attribute>
		<xsl:call-template name="item_record">
			<xsl:with-param name="type" select="$type"/>
		</xsl:call-template>
		<xsl:element name="br" />
			<xsl:for-each select="after/record">
				(<xsl:number level="single" format="1" count="after/record" />). 
				<xsl:call-template name="after_record">
					<xsl:with-param name="type" select="$type"/>
				</xsl:call-template>
				<xsl:call-template name="user_error" />
				<xsl:apply-templates select="structure">
					<xsl:with-param name="type" select="$type"/>
				</xsl:apply-templates>
			</xsl:for-each>
		</xsl:element>
	</xsl:element>
	</xsl:for-each>
	
<xsl:element name="span">
<xsl:attribute name="style">font-weight:bold;font-size:1.2em</xsl:attribute>
){
</xsl:element>

<xsl:for-each select="execute">
<xsl:element name="ul">
	<xsl:element name="li">
	<xsl:attribute name="style">margin-bottom:10;</xsl:attribute>

	<xsl:call-template name="item_record">
		<xsl:with-param name="type" select="$type"/>
	</xsl:call-template>

	<xsl:element name="br" />
		<xsl:for-each select="after/record">
			(<xsl:number level="single" format="1" count="after/record" />). 
			<xsl:call-template name="after_record">
				<xsl:with-param name="type" select="$type"/>
			</xsl:call-template>
			<xsl:call-template name="user_error" />
			<xsl:apply-templates select="structure">
				<xsl:with-param name="type" select="$type"/>
			</xsl:apply-templates>
		</xsl:for-each>
	</xsl:element>
</xsl:element>
</xsl:for-each>

<xsl:element name="span">
<xsl:attribute name="style">font-weight:bold;font-size:1.2em</xsl:attribute>
}
<xsl:element name="br" />
</xsl:element>
</xsl:for-each>

</xsl:element>

</xsl:if>

<!-- SET DATȀꍇ -->
<xsl:if test="@type[.='setData']">
<xsl:element name="span">
<xsl:attribute name="style">font-weight:bold;font-size:1.2em</xsl:attribute>
UntilEmpty ( </xsl:element>
	<xsl:for-each select="record">
	<xsl:if test="@name[.='data']">
		<xsl:call-template name="item_record">
			<xsl:with-param name="type" select="$type"/>
		</xsl:call-template>
	</xsl:if>
	</xsl:for-each>
<xsl:element name="span">
<xsl:attribute name="style">font-weight:bold;font-size:1.2em</xsl:attribute>
) {</xsl:element>

<xsl:element name="ol">
<xsl:for-each select="record">
		<xsl:if test="@name[.!='data']">
			<xsl:element name="li">
			<xsl:attribute name="style">margin-bottom:10;</xsl:attribute>

			<xsl:call-template name="item_record">
				<xsl:with-param name="type" select="$type"/>
			</xsl:call-template>
			<xsl:element name="br" />
				<xsl:for-each select="after/record">
					(<xsl:number level="single" format="1" count="after/record" />). 
					<xsl:call-template name="after_record">
						<xsl:with-param name="type" select="$type"/>
					</xsl:call-template>
					<xsl:call-template name="user_error"/>
					<xsl:apply-templates select="structure">
						<xsl:with-param name="type" select="$type"/>
					</xsl:apply-templates>
				</xsl:for-each>
			</xsl:element>
		</xsl:if>
	</xsl:for-each> 
</xsl:element>
<xsl:element name="span">
<xsl:attribute name="style">font-weight:bold;font-size:1.2em</xsl:attribute>
}
</xsl:element>



</xsl:if>


<!-- Switch Case ̏ꍇ -->
<xsl:if test="@type[.='switch']">
<xsl:element name="span">
<xsl:attribute name="style">font-weight:bold;font-size:1.2em</xsl:attribute>
Switch ( </xsl:element>
	<xsl:for-each select="record">
	<xsl:if test="@name[.='switch']">
		<xsl:call-template name="item_record">
			<xsl:with-param name="type" select="$type"/>
		</xsl:call-template>
	</xsl:if>
	</xsl:for-each>
<xsl:element name="span">
<xsl:attribute name="style">font-weight:bold;font-size:1.2em</xsl:attribute>
	 ) {</xsl:element>

<xsl:element name="ul">
<xsl:for-each select="record">
<xsl:if test="@name[.!='switch']">
	<xsl:element name="li">
	<xsl:attribute name="style">margin-bottom:10;</xsl:attribute>
	
	<xsl:element name="span">
	<xsl:attribute name="style">font-weight:bold;font-size:1.2em</xsl:attribute>
	<xsl:value-of select="@name" />:
	</xsl:element>
	
	<xsl:call-template name="item_record">
		<xsl:with-param name="type" select="$type"/>
	</xsl:call-template>
	<xsl:element name="br" />
		<xsl:for-each select="after/record">
			(<xsl:number level="single" format="1" count="after/record" />). 
			<xsl:call-template name="after_record">
				<xsl:with-param name="type" select="$type"/>
			</xsl:call-template>
			<xsl:call-template name="user_error"/>
			<xsl:apply-templates select="structure">
				<xsl:with-param name="type" select="$type"/>
			</xsl:apply-templates>
		</xsl:for-each>
	</xsl:element>
</xsl:if>
</xsl:for-each>
</xsl:element>

<xsl:element name="span">
<xsl:attribute name="style">font-weight:bold;font-size:1.2em</xsl:attribute>
}
</xsl:element>


</xsl:if>
<!-- ExecuteAfter ̏ꍇ -->
<xsl:if test="@type[.='after']">

<xsl:if test="count(record) > 0">
<xsl:element name="ul">
<xsl:for-each select="record">


	<xsl:element name="li">

	<xsl:call-template name="item_record">
		<xsl:with-param name="type" select="$type"/>
	</xsl:call-template>
	<xsl:element name="br" />

	<xsl:for-each select="after/record">
		(<xsl:number level="single" format="1" count="after/record" />). 
		<xsl:call-template name="after_record">
			<xsl:with-param name="type" select="$type"/>
		</xsl:call-template>
		<xsl:call-template name="user_error" />
		<xsl:apply-templates select="structure">
			<xsl:with-param name="type" select="$type"/>
		</xsl:apply-templates>
	</xsl:for-each>
	
	</xsl:element>
</xsl:for-each>

</xsl:element>
</xsl:if>
</xsl:if>

<!-- Orver Erroȑꍇ -->
<xsl:if test="@type[.='orver']">
	<xsl:element name="p">
	<xsl:attribute name="style">color:red;font-size:1.5em;</xsl:attribute>
	Error!! Structure is too deep.
	</xsl:element>
</xsl:if>

<xsl:element name="br" />

</xsl:template>

<!-- ******* [UG[  \ *********** -->

<xsl:template name="user_error">
<xsl:if test="user_error[.!='']">
	<xsl:element name="span">
	<xsl:attribute name="style">color:#006699;font-size:0.9em;</xsl:attribute>
	<xsl:value-of select="$USER_ERROR" />:<xsl:value-of select="user_error" />
	</xsl:element>
</xsl:if>
<xsl:if test="param[.!='']">
	<xsl:element name="span">
	<xsl:attribute name="style">color:#006699;font-size:0.9em;</xsl:attribute>
	<xsl:value-of select="$PARAMETER" />F<xsl:value-of select="param" />
	</xsl:element>
</xsl:if>


<!--
<xsl:element name="span">
	<xsl:attribute name="style">color:#gray;font-size:0.9em;</xsl:attribute>
	<xsl:attribute name="title">[<xsl:value-of select="param" />]

<xsl:apply-templates select="in_record" />
<xsl:apply-templates select="out_record" />
==== <xsl:value-of select="$PARAMETER" /> ====

[<xsl:value-of select="param" />]
	</xsl:attribute>p[^

</xsl:element>
-->
<xsl:element name="br" />
</xsl:template>


<!-- ********  ********** -->
<xsl:template match="in_record">==== IN ====
<xsl:for-each select="record">
	<xsl:number level="single" format="1" count="record" />.y<xsl:value-of select="logical_name" />z
</xsl:for-each>
</xsl:template>
<!-- ********  ********** -->
<xsl:template match="out_record">==== OUT ====
<xsl:for-each select="record">
	<xsl:number level="single" format="1" count="record" />.y<xsl:value-of select="logical_name" />z
</xsl:for-each>
</xsl:template>

<!-- ******* rWlX[  \ *********** -->
<xsl:template name="after_record">
<xsl:param name="type" />

<xsl:element name="span">
<xsl:if test="enable[.!='1']">
	<xsl:attribute name="style">text-decoration:line-through;</xsl:attribute>
</xsl:if>

<xsl:if test="base_id[.='4005']">
<xsl:element name="span">
<xsl:attribute name="style">color:red;font-weight:bold;font-size:1.2em</xsl:attribute>
throw Error <xsl:value-of select="param" /> 
</xsl:element>
</xsl:if>

<xsl:element name="a">
<xsl:if test="type[.='rule']">
<xsl:attribute name="href">
	<xsl:call-template name="create_link">
		<xsl:with-param name="data_type" select="$TARGET_CS_CRULE"/>
		<xsl:with-param name="select_type" select="2"/>
		<xsl:with-param name="id" select="./id"/>
	</xsl:call-template>
</xsl:attribute>
</xsl:if>
<xsl:if test="type[.!='rule']">
<xsl:attribute name="href">
	<xsl:call-template name="create_link">
		<xsl:with-param name="data_type" select="$TARGET_CS_CTRAN"/>
		<xsl:with-param name="select_type" select="2"/>
		<xsl:with-param name="id" select="./id"/>
	</xsl:call-template>
</xsl:attribute>
</xsl:if>
<xsl:if test="$type='p'">
	<xsl:value-of select="physical_name" />
</xsl:if>
<xsl:if test="$type=''">
	<xsl:value-of select="logical_name" />
</xsl:if>
</xsl:element>

</xsl:element>


</xsl:template>

<!-- ******** ACe̕\ ********** -->

<xsl:template name="item_record">
<xsl:param name="type" />

<xsl:element name="a">
<xsl:attribute name="href">
	<xsl:call-template name="create_link">
		<xsl:with-param name="data_type" select="$TARGET_CS_ITEM"/>
		<xsl:with-param name="select_type" select="2"/>
		<xsl:with-param name="id" select="./id"/>
	</xsl:call-template>
</xsl:attribute>

<xsl:if test="$type='p'">
	<xsl:value-of select="physical_name" />
</xsl:if>
<xsl:if test="$type=''">
	<xsl:value-of select="logical_name" />
</xsl:if>
</xsl:element>
</xsl:template>


<!-- ******** G[tOpACe̕\ ********** -->

<xsl:template name="error_flg_item_record">
<xsl:param name="type" />

<xsl:element name="a">
	<xsl:attribute name="href">
		<xsl:call-template name="create_link">
			<xsl:with-param name="data_type" select="$TARGET_CS_ITEM"/>
			<xsl:with-param name="select_type" select="2"/>
			<xsl:with-param name="id" select="../error_flg/id"/>
		</xsl:call-template>
	</xsl:attribute>
	<xsl:if test="$type='p'">
		<xsl:value-of select="../error_flg/physical_name" />
	</xsl:if>
	<xsl:if test="$type=''">
		<xsl:value-of select="../error_flg/logical_name" />
	</xsl:if>
</xsl:element>

</xsl:template>

</xsl:stylesheet>
