<?xml version="1.0" encoding="shift_jis"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" > 
<xsl:import href="./common.xsl"/>
<xsl:output method="html" doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN" />

<!-- ****** TOP ****** -->

<xsl:template match="/">
	<xsl:apply-templates select="dynamic_document">
		<xsl:with-param name="select_type" select="'2'"/>
		<xsl:with-param name="data_type" select="$TARGET_CS_CTABLE"/>
		<xsl:with-param name="id" select="$HEADER_ID"/>
	</xsl:apply-templates>
</xsl:template>

<!-- ****** HEADER ****** -->

<xsl:template match="header">
	<xsl:call-template name="sub_links"/>
	<xsl:call-template name="frame_info"/>

	<xsl:call-template name="title_tab">
		<xsl:with-param name="name" select="concat($TABLE,$DETAIL)" />
		<xsl:with-param name="image" select="$IMG_TABLE"/>
	</xsl:call-template>

<xsl:element name="table">
	<xsl:attribute name="class">main</xsl:attribute>
	<xsl:attribute name="summary"><xsl:value-of select="$TABLE" /><xsl:value-of select="$DETAIL" /></xsl:attribute>

	<xsl:element name="tr">
		<xsl:attribute name="style">width:100%</xsl:attribute>
		<xsl:element name="th">
			<xsl:attribute name="style">width:150px;</xsl:attribute><xsl:value-of select="$LOGICAL_NAME" />
		</xsl:element>
		<xsl:element name="td"><xsl:value-of select="logical_name" /></xsl:element>
	</xsl:element>

	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$PHYSICAL_NAME" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="physical_name" /></xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$COMMENT" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="memo" /></xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$COMPONENT" /></xsl:element>
		<xsl:element name="td">
			<xsl:element name="a">
				<xsl:attribute name="href">
					<xsl:call-template name="create_link">
						<xsl:with-param name="data_type" select="$TARGET_CS_COMPONENT"/>
						<xsl:with-param name="select_type" select="2"/>
						<xsl:with-param name="id" select="component/id"/>
					</xsl:call-template>
				</xsl:attribute>
				<xsl:value-of select="component/logical_name" /><xsl:element name="br" /><xsl:value-of select="component/physical_name" />
			</xsl:element>
		</xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$READ_ONLY" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="readonly" /></xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$MENU_INSERT" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="insertmenu" /></xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$MENU_COPY" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="copymenu" /></xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$MENU_DELETE" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="deletemenu" /></xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$MENU_MOVE" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="movemenu" /></xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$LAYOUT_H" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="rowheight" /></xsl:element>
	</xsl:element>

	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$ROW_RESIZE" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="resizemode" /></xsl:element>
	</xsl:element>

</xsl:element>

</xsl:template>

<!-- ****** DETAIL ****** -->

<xsl:template match="detail">
	<!-- RECORD -->
	<xsl:if test="$HREF = 'item'">
		<xsl:call-template name="records" />
	</xsl:if>
	<!-- TIMING -->
	<xsl:if test="$HREF = 'timing'">
		<xsl:call-template name="executions" />
	</xsl:if>

</xsl:template>

<!-- **************************************** -->

<xsl:template name="records">
	<xsl:element name="br" />
	<xsl:element name="table">
		<xsl:attribute name="class">main</xsl:attribute>
		<xsl:attribute name="summary">item</xsl:attribute>

		<xsl:element name="tr">
			<xsl:attribute name="style">width:100%</xsl:attribute>
			<xsl:element name="th">
				<xsl:attribute name="colspan">2</xsl:attribute><xsl:value-of select="$ITEM" />
			</xsl:element>
			<xsl:element name="th"><xsl:value-of select="$TEXT" /></xsl:element>
			<xsl:element name="th"><xsl:value-of select="$LAYOUT_W" /></xsl:element>
			<xsl:element name="th"><xsl:value-of select="$DISPLAY" /></xsl:element>
			<xsl:element name="th"><xsl:value-of select="$EDITABLE" /></xsl:element>
			<xsl:element name="th"><xsl:value-of select="$CELL_RENDERER" /></xsl:element>
			<xsl:element name="th"><xsl:value-of select="$CELL_EDITOR" /></xsl:element>
		</xsl:element>
		<xsl:for-each select="record">
			<xsl:element name="tr">
				<xsl:element name="td">
					<xsl:attribute name="class">image</xsl:attribute><xsl:call-template name="image_of_item"/>
				</xsl:element>
				<xsl:element name="td">
					<xsl:element name="a">
						<xsl:attribute name="href">
							<xsl:call-template name="create_link">
								<xsl:with-param name="data_type" select="$TARGET_CS_ITEM"/>
								<xsl:with-param name="select_type" select="2"/>
								<xsl:with-param name="id" select="item/id"/>
							</xsl:call-template>
						</xsl:attribute>
						<xsl:value-of select="item/logical_name" /><xsl:element name="br" /><xsl:value-of select="item/physical_name" />
					</xsl:element>
				</xsl:element>
				<xsl:element name="td"><xsl:value-of select="text" /></xsl:element>
				<xsl:element name="td"><xsl:value-of select="columnwidth" /></xsl:element>
				<xsl:element name="td"><xsl:value-of select="visible" /></xsl:element>
				<xsl:element name="td"><xsl:value-of select="editable" /></xsl:element>
				<xsl:element name="td"><xsl:value-of select="renderer/logical_name" /><xsl:element name="br" /><xsl:value-of select="renderer/physical_name" /></xsl:element>
				<xsl:element name="td"><xsl:value-of select="editor/logical_name" /><xsl:element name="br" /><xsl:value-of select="editor/physical_name" /></xsl:element>
			</xsl:element>
		</xsl:for-each>
	</xsl:element>
</xsl:template>

</xsl:stylesheet>
